# 🚀 programmering.no | 🤓 matematikk.as
# vekstfaktor_cas() regner ut vekstfaktoren for CAS (Matematikk AS)
# Andre navn: vekst_faktor_cas()

from matematikk import Symbol

def vekstfaktor_cas(fortegn = str(), p = Symbol("")):
    
    # Vekstfaktor er definert som V = 1 ± p / 100, p: prosentvis vekst [%]
    v = Symbol("v")
    if fortegn == "+": v = 1 + p / 100 # "+": Øker
    if fortegn == "-": v = 1 - p / 100 # "-": Minker
    
    return v

v = vekstfaktor_cas(fortegn = "+", p = Symbol("p"))

print(v) # p/100 + 1



# 🚀 programmering.no | 🤓 matematikk.as
# vekstfaktor() regner ut vekstfaktoren (Matematikk AS)
# Andre navn: vekst_faktor()

def vekstfaktor(fortegn = str(),
                p       = float(),
                rund    = -1):
    
    # Vekstfaktor er definert som V = 1 ± p / 100, p: prosentvis vekst [%]
    v = 0.0
    if fortegn == "+": v = 1 + p / 100 # "+": Øker
    if fortegn == "-": v = 1 - p / 100 # "-": Minker
    
    # Runder av svaret
    if rund != 1: v = round(v, rund)
    
    return v

v = vekstfaktor(fortegn = "+",
                p       = 3.1,
                rund    = 2)

print(v) # 1.03
